@@ -5,7 +5,7 @@
 #
 # Author: Giovanni Cannata
 #
-# Copyright 2014 - 2018 Giovanni Cannata
+# Copyright 2014 - 2020 Giovanni Cannata
 #
 # This file is part of ldap3.
 #
@@ -45,6 +45,6 @@ class ListReplicas(ExtendedOperation):
 
     def populate_result(self):
         try:
-            self.result['replicas'] = str(self.decoded_response['replicaList']) if self.decoded_response['replicaList'] else None
+            self.result['replicas'] = [str(replica) for replica in self.decoded_response] if self.decoded_response else None
         except TypeError:
             self.result['replicas'] = None
