@@ -5,7 +5,7 @@
 #
 # Author: Giovanni Cannata
 #
-# Copyright 2013 - 2018 Giovanni Cannata
+# Copyright 2013 - 2020 Giovanni Cannata
 #
 # This file is part of ldap3.
 #
@@ -27,27 +27,27 @@ import unittest
 
 from ldap3.operation.search import parse_filter, MATCH_EQUAL, MATCH_EXTENSIBLE
 from ldap3.utils.conv import escape_filter_chars
-from ldap3.protocol.schemas.edir888 import edir_8_8_8_schema
+from ldap3.protocol.schemas.edir914 import edir_9_1_4_schema, edir_9_1_4_dsa_info
 from ldap3.protocol.rfc4512 import SchemaInfo, DsaInfo
 from ldap3.core.exceptions import LDAPAttributeError, LDAPObjectClassError
-from test.config import test_auto_escape, test_auto_encode, test_check_names
+from test.config import test_auto_escape, test_auto_encode, test_validator, test_check_names
 
 
 class Test(unittest.TestCase):
     def test_parse_search_filter_equality(self):
-        f = parse_filter('(cn=admin)', None, test_auto_escape, test_auto_encode, test_check_names)
+        f = parse_filter('(cn=admin)', None, test_auto_escape, test_auto_encode, test_validator, test_check_names)
         self.assertEqual(f.elements[0].tag, MATCH_EQUAL)
         self.assertEqual(f.elements[0].assertion['attr'], 'cn')
         self.assertEqual(f.elements[0].assertion['value'], b'admin')
 
     def test_parse_search_filter_equality_2(self):
-        f = parse_filter('(cn=a<=b=>c)', None, test_auto_escape, test_auto_encode, test_check_names)
+        f = parse_filter('(cn=a<=b=>c)', None, test_auto_escape, test_auto_encode, test_validator, test_check_names)
         self.assertEqual(f.elements[0].tag, MATCH_EQUAL)
         self.assertEqual(f.elements[0].assertion['attr'], 'cn')
         self.assertEqual(f.elements[0].assertion['value'], b'a<=b=>c')
 
     def test_parse_search_filter_extensible_syntax_1(self):
-        f = parse_filter('(cn:caseExactMatch:=Fred Flintstone)', None, test_auto_escape, test_auto_encode, test_check_names)
+        f = parse_filter('(cn:caseExactMatch:=Fred Flintstone)', None, test_auto_escape, test_auto_encode, test_validator, test_check_names)
         self.assertEqual(f.elements[0].tag, MATCH_EXTENSIBLE)
         self.assertEqual(f.elements[0].assertion['attr'], 'cn')
         self.assertEqual(f.elements[0].assertion['value'], b'Fred Flintstone')
@@ -55,7 +55,7 @@ class Test(unittest.TestCase):
         self.assertEqual(f.elements[0].assertion['dnAttributes'], False)
 
     def test_parse_search_filter_extensible_syntax_2(self):
-        f = parse_filter('(cn:=Betty Rubble)', None, test_auto_escape, test_auto_encode, test_check_names)
+        f = parse_filter('(cn:=Betty Rubble)', None, test_auto_escape, test_auto_encode, test_validator, test_check_names)
         self.assertEqual(f.elements[0].tag, MATCH_EXTENSIBLE)
         self.assertEqual(f.elements[0].assertion['attr'], 'cn')
         self.assertEqual(f.elements[0].assertion['value'], b'Betty Rubble')
@@ -63,7 +63,7 @@ class Test(unittest.TestCase):
         self.assertEqual(f.elements[0].assertion['dnAttributes'], False)
 
     def test_parse_search_filter_extensible_syntax_3(self):
-        f = parse_filter('(sn:dn:2.4.6.8.10:=Barney Rubble)', None, test_auto_escape, test_auto_encode, test_check_names)
+        f = parse_filter('(sn:dn:2.4.6.8.10:=Barney Rubble)', None, test_auto_escape, test_auto_encode, test_validator, test_check_names)
         self.assertEqual(f.elements[0].tag, MATCH_EXTENSIBLE)
         self.assertEqual(f.elements[0].assertion['attr'], 'sn')
         self.assertEqual(f.elements[0].assertion['value'], b'Barney Rubble')
@@ -71,7 +71,7 @@ class Test(unittest.TestCase):
         self.assertEqual(f.elements[0].assertion['dnAttributes'], True)
 
     def test_parse_search_filter_extensible_syntax_4(self):
-        f = parse_filter('(o:dn:=Ace Industry)', None, test_auto_escape, test_auto_encode, test_check_names)
+        f = parse_filter('(o:dn:=Ace Industry)', None, test_auto_escape, test_auto_encode, test_validator, test_check_names)
         self.assertEqual(f.elements[0].tag, MATCH_EXTENSIBLE)
         self.assertEqual(f.elements[0].assertion['attr'], 'o')
         self.assertEqual(f.elements[0].assertion['value'], b'Ace Industry')
@@ -79,7 +79,7 @@ class Test(unittest.TestCase):
         self.assertEqual(f.elements[0].assertion['dnAttributes'], True)
 
     def test_parse_search_filter_extensible_syntax_5(self):
-        f = parse_filter('(:1.2.3:=Wilma Flintstone)', None, test_auto_escape, test_auto_encode, test_check_names)
+        f = parse_filter('(:1.2.3:=Wilma Flintstone)', None, test_auto_escape, test_auto_encode, test_validator, test_check_names)
         self.assertEqual(f.elements[0].tag, MATCH_EXTENSIBLE)
         self.assertEqual(f.elements[0].assertion['attr'], False)
         self.assertEqual(f.elements[0].assertion['value'], b'Wilma Flintstone')
@@ -87,7 +87,7 @@ class Test(unittest.TestCase):
         self.assertEqual(f.elements[0].assertion['dnAttributes'], False)
 
     def test_parse_search_filter_extensible_syntax_6(self):
-        f = parse_filter('(:DN:2.4.6.8.10:=Dino)', None, test_auto_escape, test_auto_encode, test_check_names)
+        f = parse_filter('(:DN:2.4.6.8.10:=Dino)', None, test_auto_escape, test_auto_encode, test_validator, test_check_names)
         self.assertEqual(f.elements[0].tag, MATCH_EXTENSIBLE)
         self.assertEqual(f.elements[0].assertion['attr'], False)
         self.assertEqual(f.elements[0].assertion['value'], b'Dino')
@@ -95,25 +95,25 @@ class Test(unittest.TestCase):
         self.assertEqual(f.elements[0].assertion['dnAttributes'], True)
 
     def test_parse_search_filter_parenteses(self):
-        f = parse_filter('(cn=' + escape_filter_chars('Doe (Missing Inc)') + ')', None, test_auto_escape, test_auto_encode, test_check_names)
+        f = parse_filter('(cn=' + escape_filter_chars('Doe (Missing Inc)') + ')', None, test_auto_escape, test_auto_encode, test_validator, test_check_names)
         self.assertEqual(f.elements[0].tag, MATCH_EQUAL)
         self.assertEqual(f.elements[0].assertion['attr'], 'cn')
         self.assertEqual(f.elements[0].assertion['value'], b'Doe \\28Missing Inc\\29')
 
     def test_parse_search_filter_bad_attribute_type_check_true(self):
-        self.assertRaises(LDAPAttributeError, parse_filter, '(bad=admin)', SchemaInfo.from_json(edir_8_8_8_schema), test_auto_escape, test_auto_encode, check_names=True)
+        self.assertRaises(LDAPAttributeError, parse_filter, '(bad=admin)', SchemaInfo.from_json(edir_9_1_4_schema), test_auto_escape, test_auto_encode, test_validator, check_names=True)
 
     def test_parse_search_filter_bad_attribute_type_check_false(self):
-        f = parse_filter('(bad=admin)', SchemaInfo.from_json(edir_8_8_8_schema), test_auto_escape, test_auto_encode, check_names=False)
+        f = parse_filter('(bad=admin)', SchemaInfo.from_json(edir_9_1_4_schema), test_auto_escape, test_auto_encode, test_validator, check_names=False)
         self.assertEqual(f.elements[0].tag, MATCH_EQUAL)
         self.assertEqual(f.elements[0].assertion['attr'], 'bad')
         self.assertEqual(f.elements[0].assertion['value'], b'admin')
 
     def test_parse_search_filter_bad_object_class_type_check_true(self):
-        self.assertRaises(LDAPObjectClassError, parse_filter, '(objectClass=bad)', SchemaInfo.from_json(edir_8_8_8_schema), test_auto_escape, test_auto_encode, check_names=True)
+        self.assertRaises(LDAPObjectClassError, parse_filter, '(objectClass=bad)', SchemaInfo.from_json(edir_9_1_4_schema), test_auto_escape, test_auto_encode, test_validator, check_names=True)
 
     def test_parse_search_filter_bad_object_class_type_check_false(self):
-        f = parse_filter('(objectClass=bad)', SchemaInfo.from_json(edir_8_8_8_schema), test_auto_escape, test_auto_encode, check_names=False)
+        f = parse_filter('(objectClass=bad)', SchemaInfo.from_json(edir_9_1_4_schema), test_auto_escape, test_auto_encode, test_validator, check_names=False)
         self.assertEqual(f.elements[0].tag, MATCH_EQUAL)
         self.assertEqual(f.elements[0].assertion['attr'], 'objectClass')
         self.assertEqual(f.elements[0].assertion['value'], b'bad')
