@@ -228,7 +228,10 @@ class Test(unittest.TestCase):
         self.assertEqual(result['description'], 'success')
         self.assertEqual(len(response), 1)
         if test_server_type == 'EDIR':
-            status, result, response, request = get_response_values(self.connection.search(search_base=test_base, search_filter='(guid=' + response[0]['attributes']['guid'] + ')', attributes=[test_name_attr, 'sn']), self.connection)
+            if self.connection.check_names:
+                status, result, response, request = get_response_values(self.connection.search(search_base=test_base, search_filter='(guid=' + response[0]['attributes']['guid'] + ')', attributes=[test_name_attr, 'sn']), self.connection)
+            else:
+                status, result, response, request = get_response_values(self.connection.search(search_base=test_base, search_filter='(guid=' + escape_bytes(response[0]['raw_attributes']['guid'][0]) + ')', attributes=[test_name_attr, 'sn']), self.connection)
         elif test_server_type == 'AD':  # not tested on AD yet
             status, result, response, request = get_response_values(self.connection.search(search_base=test_base, search_filter='(objectguid=' + response[0]['attributes']['objectguid'] + ')', attributes=[test_name_attr, 'sn']), self.connection)
         self.assertEqual(result['description'], 'success')
@@ -250,4 +253,7 @@ class Test(unittest.TestCase):
         self.assertEqual(len(response), 1)
         if test_server_type == 'EDIR':
             self.assertEqual(response[0]['attributes'][test_name_attr][0], testcase_id + 'sea-17')
-            self.assertEqual(response[0]['attributes']['audio'][0], ldap_bytes)
+            if self.connection.check_names:
+                self.assertEqual(response[0]['attributes']['audio'][0], ldap_bytes)
+            else:
+                self.assertEqual(response[0]['raw_attributes']['audio'][0], ldap_bytes)
